.. machado documentation master file, created by
   sphinx-quickstart on Fri Apr 20 13:33:22 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

machado's documentation
=======================

machado provides users with a framework to store, search and visualize biological data.

It is a framework powered by `Django <https://www.djangoproject.com/>`_ that contains tools to interact with a `Chado <http://gmod.org/wiki/Chado_-_Getting_Started>`_. 


Content
========

.. toctree::
   :maxdepth: 2
   :titlesonly:
   :numbered:

   Installation <installation>
   Data loading <dataload>
   Visualization <visualization>
   Diagrams <diagrams>
   Models <models>

* :ref:`search`
